"use strict";

var _loader = require("../components/loader");

var _lambdaLayers = require("./lambdaLayers");

var _relayPermissions = require("./relayPermissions");

const WebSocket = require("ws");

async function createRelay(apiGateway, fullLambda, program, screen, lambda, iam, application) {
  const stage = "relay-dev";
  console.log("Setting up Relay...");
  const loader = new _loader.Loader(screen, 5, 20);
  loader.load("Please wait");

  try {
    await (0, _relayPermissions.addRelayPermissions)(lambda, iam, fullLambda, stage);
    await (0, _lambdaLayers.setupLambdaLayer)(lambda, fullLambda);
    const websocketAddress = await apiGateway.createWebsocket(fullLambda, program, stage);
    const relay = new WebSocket(websocketAddress);
    relay.on("open", () => {
      console.log("Warning: Realtime logs will appear faster than CloudWatch");
      application.setRelayActive(true); // Clear and reset logs

      application.lambdaLog.generateLog();
    });
    relay.on("message", data => {
      application.lambdaLog.log(data);
    });
    relay.on("close", () => {
      console.log("Relay Closed");
    });
    relay.on("error", console.error);
  } catch (e) {
    console.error("Relay Setup Failure");
    console.error(e);
  }

  loader.stop();
  loader.destroy();
}

module.exports = {
  createRelay
};